
class PredictInterface:
    def init(self, provider: str):
        """Load the model."""
        pass

    def model_artifact(self):
        """Get the file directory and model path"""
        pass

    def endpoint_metadata():
        pass